

// Occupation and the Political Economy of Trade
// Author: Erica Owen 1-11-2017

/* Note this file produces all summary statistics reported in main text
and online appendix */

version 14
clear all
macro drop _all
set linesize 80

// #1
// Load data
use  "data.dta", clear



// #2 
// Summary statistics (Table 7)

foreach i in 2003 2013 {
local myvars limitimp c_rti offshorable_bl schoolyrs lnCA lnCD  ///
	nationalindex unemp uniondum sex age c_routineness c_offshor2 damageMNCrev
sum `myvars' if year==`i'


// #3
// Correlation of all variables (Table A1)
pwcorr `myvars' if year==`i',sig
}

// #4
// Correlation of key IVs (Table 2)
foreach i in 2003 2013 {
local myvars2 limitimp c_rti offshorable_bl schoolyrs lnCA lnCD 
pwcorr `myvars2' if year==`i',sig
	}

// #5 
// Graphs

// Mean support protection in 2003 - Figure 1 
graph bar limitimp if year==2003, over(countryname1, label(angle(45) labsize(small))) over(year) ytitle("Mean of favor limiting imports")  nofill

// Mean support protection in 2013 - Figure A1
graph bar limitimp if year==2013, over(countryname1, label(angle(45) labsize(small))) over(year) ytitle("Mean of favor limiting imports")  nofill

// Graph of DV by country - Figures A2 and A3  
foreach i in 2003 2013 {
hist limitimp if year==`i', by(countryname1) percent dis gap(50) xlabel(1(1)5, valuelabel angle(45) labsize(small)) xtitle("Country should limit imports to protection national economy", size(small))
}



	
