
capture log close


// Occupation and the Political Economy of Trade
// Author: Erica Owen 1-11-2017

/* Note this file produces the main results presented in Table 3
and corresponding marginal effects plots */

// #0
// program setup



version 14
clear all
macro drop _all
set linesize 80

// #1
// Load data  
use  "data.dta", clear


// #2
// Specify variables
local dv limitimp
local ivs c_rti offshorable_bl
local myint c.c_rti##c.offshorable_bl
local controls schoolyrs  nationalindex unemp uniondum sex age lnCA lnCD i.ccode 

// #3
// Run main models (Models 1-4 of Table 3)

foreach i in 2003 2013 {
reg `dv' `ivs' `controls' [aw=weight] if year==`i', cluster(ccode)
est sto m1_`i'
estat ic

reg `dv' `myint' `controls' [aw=weight] if year==`i', cluster(ccode)
est sto m2_`i'
estat ic
}

// #4 
// Run models restricted sample (Models 5 and 6 of Table 3)



reg `dv' `myint' `controls' [aw=weight] if  year==2003 & ressamp==1, cluster(ccode)
est sto m3_2003
estat ic

reg `dv' `myint' `controls' [aw=weight] if year==2013  & ressamp==1, cluster(ccode)
est sto m3_2013
estat ic



 
 // Figure 4
// Generate coefficient plots for restricted sample
 
 coefplot m3_2003 m3_2013, xline(0) ///
	drop(5.ccode 6.ccode 7.ccode 9.ccode 13.ccode 14.ccode 15.ccode 19.ccode ///
		21.ccode 24.ccode 27.ccode 26.ccode 28.ccode 29.ccode 30.ccode 32.ccode 33.ccode  _cons) ///
	plotlabel("2003" "2013") order(c_rti offshorable_bl c.c_rti#c.offshorable_bl schoolyrs lnCD lnCA nationalindex) ///
	name(cfp, replace) levels(95) note("Estimates from Table 3, Models 5 and 6. 95% confidence intervals.")
	
	


// Marginal effects plots for main text
// This file uses a .do file
// You must set your working directory to the folder containing meplot.do
// This file will output 2 combined marginal effects plot 


// 1. graph ``comb'' is Figure 2 
// 2. graph ``comb2'' is Figure 3


global model2003 m2_2003 
global model2013 m2_2013 
global dv support for protection
do "meplot.do"

// Note the above figures will be over written by the next bit of code


// Marginal effect plot for restricted sample (Figures A4 and A5 of online app.)
// This file also uses the same meplot.do

// 1. graph ``comb'' is Figure A4
// 2. graph ``comb2'' is Figure A5

global model2003 m3_2003
global model2013 m3_2013
global dv support for protection
do "meplot.do"

