

capture log close

// Occupation and the Political Economy of Trade
// Author: Erica Owen 1-11-2017


/* Note: This file produces results  reported in Tables A4 (2003) 
	and A5 (2013) as well the comparison of BICs
	graphed in Figure 1 of main text. 
	
*/

// #0
// program setup




// Set working directory to location of the data

version 14.1
clear all
macro drop _all
set linesize 80

// #1
// Load data 
use  "data.dta", clear


// #2
// Run models and collect BIC, AIC



// Specify variables
local dv limitimp
local ivs c_rti c.offshorable_bl
local myint c.c_rti##c.offshorable_bl
local controls2 schoolyrs  nationalindex unemp uniondum sex age lnCA lnCD i.ccode 


capture gen aic2003=.
capture gen bic2003=.
capture gen aic2013=.
capture gen bic2013=.

foreach i in 2003 2013 {

// Factor model (only years of schooling)
quietly reg `dv' schoolyrs  nationalindex unemp uniondum sex age i.ccode  ///
	[aw=weight] if year==`i', cluster(ccode)
quietly estat ic
est sto m1_`i'
matrix r`i'_1=r(S)
replace aic2003=r`i'_1[1,5] in 1 if `i'==2003
replace bic2003=r`i'_1[1,6] in 1 if `i'==2003
replace aic2013=r`i'_1[1,5] in 1 if `i'==2013
replace bic2013=r`i'_1[1,6] in 1 if `i'==2013

// Factor plus industry (schooling, plus industry comparative advantage & dis.)
quietly reg `dv'   `controls2'  [aw=weight] if year==`i', cluster(ccode)
est sto m2_`i'
quietly estat ic
matrix r`i'_2=r(S)
replace aic2003=r`i'_2[1,5] in 2 if `i'==2003
replace bic2003=r`i'_2[1,6] in 2 if `i'==2003
replace aic2013=r`i'_2[1,5] in 2 if `i'==2013
replace bic2013=r`i'_2[1,6] in 2 if `i'==2013

// Factor plus occupation (schooling + RTI+off+RTI*off)

quietly reg `dv' `myint'  schoolyrs  nationalindex unemp uniondum sex age i.ccode  [aw=weight] if year==`i', cluster(ccode)
quietly estat ic
est sto m3_`i'
matrix r`i'_3=r(S)
replace aic2003=r`i'_3[1,5] in 3 if `i'==2003
replace bic2003=r`i'_3[1,6] in 3 if `i'==2003
replace aic2013=r`i'_3[1,5] in 3 if `i'==2013
replace bic2013=r`i'_3[1,6] in 3 if `i'==2013

// Full model (factor+industry+occupation variables)

quietly reg `dv' `myint'  `controls2'  [aw=weight] if year==`i', cluster(ccode)
quietly estat ic
est sto m4_`i'
matrix r`i'_4=r(S)
replace aic2003=r`i'_4[1,5] in 4 if `i'==2003
replace bic2003=r`i'_4[1,6] in 4 if `i'==2003
replace aic2013=r`i'_4[1,5] in 4 if `i'==2013
replace bic2013=r`i'_4[1,6] in 4 if `i'==2013

// Combined offshorability model (RTI*off + School*Off)
 
quietly reg limitimp c.c_rti##c.offshorable_bl c.offshorable_bl##c.c_schoolyrs nationalindex unemp uniondum sex age lnCA lnCD i.ccode  [aw=weight] if year==`i', cluster(ccode)
quietly estat ic
est sto m5_`i'
matrix r`i'_5=r(S)
replace aic2003=r`i'_5[1,5] in 5 if `i'==2003
replace bic2003=r`i'_5[1,6] in 5 if `i'==2003
replace aic2013=r`i'_5[1,5] in 5 if `i'==2013
replace bic2013=r`i'_5[1,6] in 5 if `i'==2013

// Occupation only (not reported in figure)
quietly reg `dv' `myint' nationalindex unemp uniondum sex age i.ccode   [aw=weight] if year==`i', cluster(ccode)
quietly estat ic
matrix r`i'_6=r(S)
replace aic2003=r`i'_6[1,5] in 6 if `i'==2003
replace bic2003=r`i'_6[1,6] in 6 if `i'==2003
replace aic2013=r`i'_6[1,5] in 6 if `i'==2013
replace bic2013=r`i'_6[1,6] in 6 if `i'==2013

// Industry only (non reported in figure)
quietly reg `dv' lnCA lnCD nationalindex unemp uniondum sex age i.ccode   [aw=weight] if year==`i', cluster(ccode)
quietly estat ic
matrix r`i'_7=r(S)
replace aic2003=r`i'_7[1,5] in 7 if `i'==2003
replace bic2003=r`i'_7[1,6] in 7 if `i'==2003
replace aic2013=r`i'_7[1,5] in 7 if `i'==2013
replace bic2013=r`i'_7[1,6] in 7 if `i'==2013

}


// BIC FIGURE
capture gen mnum=1 in 1
replace mnum = 2 in 2
replace mnum = 3 in 3
replace mnum = 4 in 4
replace mnum = 5 in 5
replace mnum = 6 in 6
replace mnum = 7 in 7

label define model 1 "Factor" 2 "Factor+industry" 3 "Factor+occupation" 4 "Factor+industry+occupation" ///
	5 "Combined offshorability", replace
	
label values mnum model

sum aic* bic* if mnum==6 // occupation only
sum aic* bic* if mnum==7 // industry only
replace aic2003=. if mnum>5
replace bic2003=. if mnum>5
replace aic2013=. if mnum>5
replace bic2013=. if mnum>5
replace mnum=. if mnum>5



// BIC figure

graph twoway ///
	(scatter mnum bic2003, msymbol(O) mcolor(gray)  msize(medlarge)), ///
	yscale(reverse) ///
	legend(off) ///
	ylabel(,grid glwidth(medthin) glcolor(gs12) valuelabel labsize(small)) ///
	title("2003") xlabel(,grid glwidth(medthin) glcolor(gs12) labsize(small)) ///
	ytitle("") xtitle("BIC") name(g2003, replace)
	
	
graph twoway ///
	(scatter mnum bic2013, msymbol(O) mcolor(gray)  msize(medlarge)), ///
	yscale(reverse) ///
	legend(off) ///
	ylabel(,grid glwidth(medthin) glcolor(gs12) valuelabel labsize(small)) ///
	title("2013") xlabel(,grid glwidth(medthin) glcolor(gs12) labsize(small)) ///
	ytitle("") xtitle("BIC") name(g2013, replace)
	
graph combine g2003 g2013, imargins(tiny) ycommon name(gaic, replace)

	
