
capture log close

// Occupation and the Political Economy of Trade
// Author: Erica Owen 1-11-2017


/* Note: this file produces all models estimated using alternative measures of
the dependent variable. This includes results in Table 4 of the main text
as well as Tables A6 and A7 of the supplemental appendix */


// #0
// program setup



version 14
clear all
macro drop _all
set linesize 80

// #1
// Load data  

use  "data.dta", clear


// Opposition to MNC activity
// Table 4 of main text 

local dv damageMNCrev
local ivs c_rti offshorable_bl
local myint c.c_rti##c.offshorable_bl
local controls schoolyrs  nationalindex unemp uniondum sex age lnCA lnCD i.ccode 


foreach i in 2003 2013 {

reg `dv' `myint' `controls' [aw=weight] if year==`i', cluster(ccode)
est sto m1_`i'
estat ic
}



 
// Create marginal effects plots for main text
// Figures 5 and 6 of main text

// This file uses a .do file
// You must set your working directory to the folder containing meplot.do
// This file will output 2 combined marginal effects plot 

// 1. Table 4, Model 1 (comb) Figure 5
// 2. Table 4, Model 2 (comb2) Figure 6


global model2003 m1_2003
global model2013 m1_2013
global dv opposition to MNCs
do "meplot.do"

 
////////////////////////////////////////
// Additional measures of the DV
// Results for 2003 in Table A6 of supplemental
// Results for 2013 in Table A7 of supplemental 
//////////////////////////////////////

local ivs c_rti offshorable_bl
local myint c.c_rti##c.offshorable_bl
local controls schoolyrs  nationalindex unemp uniondum sex age lnCA lnCD i.ccode 


foreach i in 2003 2013 {
	foreach y of varlist limitimp damageMNCrev immjobs goodsTR protect {
	reg `y' `myint' `controls' [aw=weight] if year==`i', cluster(ccode)
	est sto m`i'_`y'
	estat ic 
	}
}
