
capture log close

// Occupation and the Political Economy of Trade
// Author: Erica Owen 1-11-2017

/* 
Note: This file estimates models using alternative measures of the key
independent variables. These results are Table 5 of the main text
*/

// #0
// program setup



version 14
clear all
macro drop _all
set linesize 80

// #1
// Load data 
use  "data.dta", clear


// #2
// Alternative independent variables

local dv1 limitimp
local controls2 schoolyrs  nationalindex unemp uniondum sex age lnCA lnCD i.ccode 


local myint1 c.c_routineness##i.offshorable_bl // Models 1 and 3
local myint2 c.c_routineness##c.c_offshor2 // Models 2 and 4

foreach i in 2003 2013 {

reg `dv1' `myint1' `controls2'  [aw=weight] if year==`i', cluster(ccode)
est sto m1_`i'
estat ic


reg `dv1' `myint2' `controls2'  [aw=weight] if year==`i', cluster(ccode)
est sto m2_`i'
estat ic




}

 

 
// Create marginal effects plots 
// Figures A6-A9 of supplemental appendix


// Figures A6 (2003) and A8 (2013) 
foreach i in 2003 2013 {
est restore m1_`i'
quietly margins, dydx(c_routineness) at(offshorable_bl =(0 1)) atmeans noatlegend 
marginsplot, name(g1_`i', replace) title("(A) Marginal effect absolute routineness", size(medsmall)) ///
	ytitle("Marginal effect") plotopts(msymbol(0) mcolor(red)) xtitle("Offshorability") ///
	 yline(0) ylabel(0(.02).12) 

quietly margins, dydx(offshorable_bl) at(c_routineness=(-6(1)5)) atmeans noatlegend
marginsplot, name(g2_`i', replace) yline(0) title("(B) Marginal effect of offshorability", size(medsmall))  ///
	ytitle("") xtitle("Routineness (absolute)")  plotopts(msymbol(0) mcolor(red))

graph combine g1_`i' g2_`i', imargins(tiny) name(comb_`i', replace) note("95 % confidence interval")


}

// Figures A7 (2003) and A9 (2013) 
foreach i in 2003 2013 {
est restore m2_`i'
quietly margins, dydx(c_routineness) at(c_offshor2=(-2.5(.25)3.25)) atmeans noatlegend 
marginsplot, name(g1_`i', replace) title("(A) Marginal effect absolute routineness", size(medsmall)) ///
	ytitle("Marginal effect") xtitle("Offshorability (AA)") yline(0) xlabel(-2.5(.5)3) ///
	plotopts(msymbol(0) mcolor(red)) xtitle("Offshorability (AA)") 


quietly margins, dydx(c_offshor2) at(c_routineness=(-6(1)5)) atmeans noatlegend
marginsplot, name(g2_`i', replace) yline(0) title("(B) Marginal effect of offshorability (AA)", size(medsmall))  ///
	ytitle("") xtitle("Routineness (absolute)") ///
	plotopts(msymbol(0) mcolor(red)) 

graph combine g1_`i' g2_`i', imargins(tiny) name(comb2_`i', replace) note("95 % confidence interval")

}
