
capture log close

// Occupation and the Political Economy of Trade
// Author: Erica Owen 1-11-2017


/* Note: this file examines plots additional interactions between 
offshorability and routineness, and offshorability and schooling

Results presented in Figures A10 and A11 of supplemental appendix 

*/


// #0
// program setup




version 14.1
clear all
macro drop _all
set linesize 80

// #1
// Load data 
use  "data.dta", clear


// #2
// Specify variables
local dv limitimp
local controls  nationalindex unemp uniondum sex age lnCA lnCD i.ccode 
local myint2 c.c_rti##c.offshorable_bl c.offshorable_bl##c.c_schoolyrs 




// #3
// Run models
foreach i in 2003 2013 {


reg `dv' `myint2' `controls'  [aw=weight] if year==`i', cluster(ccode)
est sto m2_`i'
estat ic


}


 // Generate marginal effects plots
 // Figures 10 and 11 of supplemental
 
 // Marginal effect of offshorability by schooling and routineness
 
 foreach i in 2003 2013 {
	est restore m2_`i'
	sum c_school if e(sample)
	local means `r(mean)'
	sum c_rti if e(sample)
	local meanr `r(mean)'
	margins, dydx(offshorable_bl) at(c_school=`means' c_rti=(-2(.5)2.5))
	marginsplot, yline(0) name(g1_`i', replace) ytitle("Marginal effect of offshorability") ///
		title("(A) Conditional on RTI") plotopts(mcolor(red) msymbol(O))
	margins, dydx(offshorable_bl) at(c_school=(-12(1)7) c_rti=(`meanr'))
	marginsplot, yline(0) name(g2_`i', replace) ytitle("") ///
		title("(B) Conditional on education")  plotopts(mcolor(red) msymbol(O))
	graph combine g1_`i' g2_`i', imargins(small) name(c_`i', replace)

	}

// Marginal effect of routineness and schooling by offshorabiltiy

foreach i in 2003 2013 {

	est restore m2_`i'
	
	margins, dydx(c_rti) at(offshorable_bl=(0 1))
	marginsplot, yline(0) name(g1_`i', replace) ytitle("Marginal effect") ///
		title("(C) Marginal effect of RTI")  xtitle("Offshorability")  plotopts(mcolor(red) msymbol(O))
	margins, dydx(c_schoolyrs) at(offshorable_bl=(0 1))
	marginsplot, yline(0) name(g2_`i', replace) ytitle("") ///
		title("(D) Marginal effect of schooling") xtitle("Offshorability")  plotopts(mcolor(red) msymbol(O))
		
	graph combine g1_`i' g2_`i', imargins(small) name(c_`i', replace) note("95% confidence interval")
	}
	
