
capture log close


// Occupation and the Political Economy of Trade
// Author: Erica Owen 1-11-2017

/* Note: this file examines changes in routineness over time.
the results are presented in Table A9 in the supplemental appendix. */

// #0
// program setup



version 14
clear all
macro drop _all
set linesize 80

// #1
// Load data  
use  "data.dta", clear

// #4 
// Run models on limited sample

keep if ressamp==1

// Pooled model with year dummy
local dv limitimp
local myint  c.c_rti##c.offshorable_bl i.year  
local controls schoolyrs lnCD lnCA nationalindex unemp uniondum sex age  i.ccode 


reg `dv' `myint' `controls' [aw=weight], cluster(ccode)
est sto m1
estat ic

// Interact offshorability, routineness and year dummy
// Table 9 of supplemental appendix
local dv limitimp
local myint  c.c_rti##c.offshorable_bl##i.year  
local controls schoolyrs lnCD lnCA nationalindex unemp uniondum sex age  i.ccode 


reg `dv' `myint' `controls' [aw=weight], cluster(ccode)
est sto m2
estat ic
test 2013.year 2013.year#c.c_rti 2013.year#c.offshorable_bl 2013.year#c.c_rti#c.offshorable_bl


// marginal effects

// Figure A12 of supplemental appendix

margins, dydx(c_rti) at(offshorable_bl=(0 1) year=(2003 2013) )
marginsplot, name(merout, replace) title("Marginal effect of routineness") ///
	legend(pos(4) ring(0)) yline(0,lpattern(dash) lcolor(gray))

margins, dydx(offshorable_bl) at(c_rti=(-2(.5)2.5) year=(2003 2013) )
marginsplot, name(meoff, replace) title("Marginal effect of offshorability") ///
	legend(pos(4) ring(0)) yline(0,lpattern(dash) lcolor(gray))


graph combine merout meoff, imargins(small)	name(comb, replace) note("95 % confidence intervals.")

